@@ -1394,7 +1394,7 @@ gchar *purple_utf8_strip_unprintables(const gchar *str);
  * @return The UTF-8 error message.
  * @since 2.4.0
  */
-G_CONST_RETURN gchar *purple_gai_strerror(gint errnum);
+const gchar *purple_gai_strerror(gint errnum);
 
 /**
  * Compares two UTF-8 strings case-insensitively.  This comparison is
